<?php
/**
 * VioletConnect REST API
 *
 * Registers checkout based endpoints for WC-API.
 *
 * @author   Rhen zabel
 * @category API
 * @package  VioletConnect/API
 * @since    1.0.1
 * @version  1.0.1
 */

if ( ! defined( 'ABSPATH' ) ) {
   exit; // Exit if accessed directly
}

/**
 * VioletConnect REST API class.
 */
class VioletConnect_Rest_API {
	/**
	 * Setup class.
	 *
	 * @access  public
	 * @since   1.0.1
	 * @version 1.0.1
	 */
	public function __construct() {
		$this->violet_init_rest_api();
	}


	/**
	 * Init Violet REST API.
	 *
	 * @access  private
	 * @since   1.0.1
	 * @version 1.0.1
	 */
	private function violet_init_rest_api() {
    // exit if no WP_REST_Server
		if ( ! class_exists( 'WP_REST_Server' ) ) {
			return;
		}

		// exit if WooCommerce is not installed
		if ( ! class_exists( 'WooCommerce' ) ) {
			return;
		}

		// Include REST API Controllers.
		add_action( 'wp_loaded', array( $this, 'rest_api_includes' ), 5 );

		// Register CoCart REST API routes.
		add_action( 'rest_api_init', array( $this, 'register_cart_routes' ), 10 );
	} // cart_rest_api_init()


	/**
	 * Include Violet REST API controllers.
	 *
	 * @access  public
	 * @since   1.0.1
	 * @version 1.0.1
	 */
	public function rest_api_includes() {
		include_once( dirname( __FILE__ ) . '/api/wc-v2/class-wc-rest-cart-controller.php' );
	}


	/**
	 * Register Violet REST API routes.
	 *
	 * @access  public
	 * @since   1.0.1
	 * @version 1.0.1
	 */
	public function register_cart_routes() {
		$controllers = array(
			'WC_REST_Cart_Controller'
		);

		foreach ( $controllers as $controller ) {
			$this->$controller = new $controller();
			$this->$controller->register_routes();
		}
	}
}

return new VioletConnect_Rest_API();
