<?php
/**
* Plugin Name: Violet
* Plugin URI: https://violet.io
* Version: 1.1.2
* Author: Violet
* Author URI: https://violet.io
* Developer: rhen@violet.io
* Description: Integrate Violet into your WooCommerce store to enable omnichannel product distribution.
* Text Domain: violet
*
* License: GPL2
* License URI: https://www.gnu.org/licenses/gpl-2.0.html
*/


/* Copyright 2017-2022 Violet.io, Inc

		This program is free software; you can redistribute it and/or modify
		it under the terms of the GNU General Public License, version 2, as
		published by the Free Software Foundation.

		This program is distributed in the hope that it will be useful,
		but without any warranty; without even the implied warranty of
		merchantability or fitness for a particular purpose. See the
		GNU General Public License for more details.

		You should have received a copy of the GNU General Public License
		along with this program; if not, write to the Free Software
		Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/



class VioletConnect {

	public function __construct() {
		$this->plugin               = new stdClass;
		$this->plugin->displayName  = 'Violet';
		$this->plugin->name         = 'violet-connect';
    	$this->plugin->version      = '1.1.2';
		$this->plugin->url          = plugin_dir_url( __FILE__ );
		$this->plugin->folder       = plugin_dir_path( __FILE__ );
		$this->plugin->db_welcome_dismissed_key = $this->plugin->name . '_welcome_dismissed_key';

		$this->define('VIOLET_FILE_PATH', untrailingslashit( plugin_dir_path( __FILE__ ) ) );

		// Include required files.
		add_action( 'init', array( $this, 'includes' ) );
		add_action( 'admin_menu', array( &$this, 'adminViews' ) );
		add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), array( $this, 'plugin_action_links' ) );
		add_filter('wp_is_application_passwords_available', '__return_false');
	}

	private function define( $name, $value ) {
		if ( ! defined( $name ) ) {
			define( $name, $value );
		}
	}

	/**
	 * Includes Checkout REST-API for WooCommerce.
	 *
	 * @access  public
	 * @since   1.0.1
	 * @version 1.0.1
	 * @return  void
	 */
	 public function includes() {
		include_once( VIOLET_FILE_PATH . '/includes/class-violet-rest-api.php' );
	}

	/**
	 * Adds plugin action links
	 *
	 * @param array $links Plugin action link before filtering.
	 *
	 * @return array Filtered links.
	 */
	public function plugin_action_links( $links ) {
		$setting_link = $this->get_setting_link();

		$plugin_links = array(
				'<a href="' . $setting_link . '">' . __( 'Settings', 'violet-connect' ) . '</a>',
				'<a href="https://docs.violet.io/merchant-docs/woo-commerce" target="_blank">' . __( 'Docs', 'violet-connect' ) . '</a>'
		);

		return array_merge( $plugin_links, $links );
	}

	/**
	 * Get setting link.
	 *
	 * @since 1.0.5
	 *
	 * @return string Setting link
	 */
	public function get_setting_link() {
		return admin_url( 'options-general.php?page=violet-connect' );
	}


	// /**
  // * Init the settings view
  // */
  function adminViews() {
		add_options_page( $this->plugin->displayName, $this->plugin->displayName, 'manage_options', 'violet-connect', array($this, 'adminSettingsView') );
	}


  // /**
  // * Render the Administration View
  // * handle persistence of settings data
  // */
  function adminSettingsView() {
		// limit access to admin users
		if ( !current_user_can( 'administrator' ) ) {
			echo '<p>' . __( 'You must be an administrator to access this page.', $this->plugin->name ) . '</p>';
			return;
		}

		// Save Settings
		if ( isset( $_REQUEST['submit'] ) ) {

			// handle missing nonce
			if ( !isset( $_REQUEST[$this->plugin->name.'_nonce'] ) ) {
				$this->errorMessage = __( 'Missing nonce field. Settings could not be updated.', $this->plugin->name );
			} elseif ( !wp_verify_nonce( $_REQUEST[$this->plugin->name.'_nonce'], $this->plugin->name ) ) {
				// validate nonce
				$this->errorMessage = __( 'Invalid nonce field. Settings could not be updated.', $this->plugin->name );
			} else {
				// persist settings
				update_option( 'violet_shipment_module', $_REQUEST['violet_shipment_module'] );
				$this->message = __( 'Settings have been successfully updated!', $this->plugin->name );
			}
		}

		// query for updated settings
		$this->settings = array (
			'violet_merchant_id' => esc_html( wp_unslash( get_option( 'violet_merchant_id' ) ) ),
			'violet_shipment_module' => esc_html( wp_unslash( get_option( 'violet_shipment_module' ) ) ),
			'violet_payouts_link' => esc_html( wp_unslash( get_option( 'violet_payouts_link' ) ) ),
			'violet_connection_status' => esc_html( wp_unslash( get_option( 'violet_connection_status' ) ) )
		);

    include_once( WP_PLUGIN_DIR . '/' . $this->plugin->name . '/views/settings.php' );
  }
}

$violetConnect = new VioletConnect();
